Debugging utilities for tui-dispatch.
This crate will host headless debug sessions, snapshot tooling, and action replay helpers built on top of tui-dispatch-core.
Re-exports
pub use cli::DebugCliArgs;pub use replay::ReplayItem;pub use session::DebugActionRecorder;pub use session::DebugRunOutput;pub use session::DebugSession;pub use session::DebugSessionError;pub use snapshot::load_json;pub use snapshot::save_json;pub use snapshot::ActionSnapshot;pub use snapshot::SnapshotError;pub use snapshot::SnapshotResult;pub use snapshot::StateSnapshot;