#[unsafe(no_mangle)]pub unsafe extern "C" fn libsession_session_id_free(
string: *mut c_char,
)Expand description
Frees a string returned by this library, such as an ID from
libsession_session_get_id.
Safety
string must be null or a pointer returned by this library that has not
already been freed. The pointer must not be used after this call.